@@ -1,7 +1,7 @@
 /*
  * Global program option structure and the parsing function prototype.
  *
- * Copyright 2008 Andrew Wood, distributed under the Artistic License 2.0.
+ * Copyright 2010 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifndef _OPTIONS_H
@@ -21,6 +21,7 @@ struct opts_s {           /* structure describing run-time options */
 	unsigned char timer;           /* timer flag */
 	unsigned char eta;             /* ETA flag */
 	unsigned char rate;            /* rate counter flag */
+	unsigned char average_rate;    /* average rate counter flag */
 	unsigned char bytes;           /* bytes transferred flag */
 	unsigned char force;           /* force-if-not-terminal flag */
 	unsigned char cursor;          /* whether to use cursor positioning */
@@ -39,6 +40,7 @@ struct opts_s {           /* structure describing run-time options */
 	int argc;                      /* number of non-option arguments */
 	char **argv;                   /* array of non-option arguments */
 	char *current_file;            /* current file being read */
+	unsigned char exit_status;     /* exit status to give (0=OK) */
 };
 
 extern opts_t opts_parse(int, char **);
