@@ -1,7 +1,7 @@
 /*
  * Parse command-line options.
  *
- * Copyright 2008 Andrew Wood, distributed under the Artistic License 2.0.
+ * Copyright 2010 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,6 +55,7 @@ opts_t opts_parse(int argc, char **argv)
 		{"timer", 0, 0, 't'},
 		{"eta", 0, 0, 'e'},
 		{"rate", 0, 0, 'r'},
+		{"average-rate", 0, 0, 'a'},
 		{"bytes", 0, 0, 'b'},
 		{"force", 0, 0, 'f'},
 		{"numeric", 0, 0, 'n'},
@@ -74,7 +75,7 @@ opts_t opts_parse(int argc, char **argv)
 	};
 	int option_index = 0;
 #endif
-	char *short_options = "hVpterbfnqcWs:li:w:H:N:L:B:R:";
+	char *short_options = "hVpterabfnqcWs:li:w:H:N:L:B:R:";
 	int c, numopts;
 	opts_t opts;
 
@@ -175,6 +176,10 @@ opts_t opts_parse(int argc, char **argv)
 			opts->rate = 1;
 			numopts++;
 			break;
+		case 'a':
+			opts->average_rate = 1;
+			numopts++;
+			break;
 		case 'b':
 			opts->bytes = 1;
 			numopts++;
@@ -259,6 +264,8 @@ opts_t opts_parse(int argc, char **argv)
 		opts->argv[opts->argc++] = argv[optind++];
 	}
 
+	opts->exit_status = 0;
+
 	return opts;
 }
 
